@@ -16,6 +16,7 @@ pub enum Hook {
     SetOutputPrompt,
     WhileCompiling,
     AfterCompile,
+    Shutdown,
 }
 
 #[derive(Eq, PartialEq, Debug, Serialize, Deserialize)]
@@ -29,7 +30,11 @@ pub enum Command {
     AcceptSuggestion,
     Continue,
     DeleteNextWord,
-    DeleteUntilNewLine(bool),
+    DeleteTillEnd,
+    DeleteUntilChar(char, bool),
+    MoveForwardTillChar(char),
+    MoveBackwardTillChar(char),
+    PrintInput,
     Multiple(Vec<Command>),
     SetThinCursor,
     SetWideCursor,
@@ -40,6 +45,7 @@ pub enum Command {
     HandleBackTab,
     HandleRight,
     HandleLeft,
+    GoToLastRow,
     HandleBackSpace,
     HandleDelete,
     HandleCtrlC,
